@@ -1,9 +1,8 @@
 # standard imports
 import logging
-import argparse
-#import enum
+import argparse #import enum
 #import os
-#import select
+import select
 import sys
 #import re
 
@@ -17,26 +16,34 @@ from aiee.arg import (
 logg = logging.getLogger(__name__)
 
 
-#def stdin_arg():
-#    """Retreive input arguments from stdin if they exist.
-#
-#    Method does not block, and expects arguments to be ready on stdin before being called.
-#
-#    :rtype: str
-#    :returns: Input arguments string
-#    """
-#    h = select.select([sys.stdin], [], [], 0)
-#    if len(h[0]) > 0:
-#        v = h[0][0].read()
-#        return v.rstrip()
-#    return None
+def stdin_arg():
+    """Retreive input arguments from stdin if they exist.
+
+    Method does not block, and expects arguments to be ready on stdin before being called.
+
+    :rtype: str
+    :returns: Input arguments string
+    """
+    h = select.select([sys.stdin], [], [])
+    if len(h[0]) > 0:
+        v = h[0][0].read()
+        return v.rstrip()
+    return None
+
 
 class ArgumentParser(argparse.ArgumentParser):
 
     def parse_args(self, argv=sys.argv[1:]):
         if '--dumpconfig' in argv:
             argv = [argv[0], '--dumpconfig']
-        return super(ArgumentParser, self).parse_args(args=argv)
+        arg = super(ArgumentParser, self).parse_args(args=argv)
+        return arg
+
+
+    def add_argument(self, *args, **kwargs):
+        if args[0][0] != '-':
+            kwargs['nargs'] = '*'
+        super(ArgumentParser, self).add_argument(*args, **kwargs)
 
 
 class ArgFlag(BaseArgFlag):
@@ -69,6 +76,8 @@ class ArgFlag(BaseArgFlag):
         self.add('veryverbose')
         self.add('path')
         self.add('backend')
+        self.add('value')
+        self.add('tab')
 
         self.alias('sign', 'key_file', 'send')
         self.alias('std_base', 'verbose', 'config', 'raw', 'env', 'target')
@@ -82,7 +91,6 @@ class Arg(BaseArg):
     
     def __init__(self, flags):
         super(Arg, self).__init__(flags)
-        
         self.add_long('no-logs', 'verbose', typ=bool, help='Turn off all logging')
         self.add('v', 'verbose', typ=bool, help='Be verbose')
         self.add('vv', 'verbose', check=False, typ=bool, help='Be more verbose')
@@ -131,13 +139,19 @@ class Arg(BaseArg):
         self.add('s', 'send', typ=bool, help='Send to network')
         self.set_long('s', 'send')
 
-        self.add_long('raw', 'raw', typ=bool, help='Do not decode output')
+        self.add('r', 'raw', typ=bool, help='Do not decode output')
+        self.set_long('r', 'raw')
         self.add('0', 'raw', typ=bool, help='Omit newline to output')
 
         self.add_long('nonce', 'nonce', typ=int, help='override nonce')
         self.add_long('fee-price', 'fee', typ=int, help='override fee price')
         self.add_long('fee-limit', 'fee', typ=int, help='override fee limit')
 
+        self.add_long('total', 'value', typ=bool, help='Deduct calculated fee from value')
+
         self.add_long('state-path', 'path', help='Path to store state data under')
         self.add_long('runtime-path', 'path', help='Path to store volatile data under')
         self.add_long('backend', 'backend', help='Backend to use for data storage')
+
+        self.add('o', 'tab', typ=str, action='append', help='Include output by key name')
+        self.set_long('o', 'output-key')
