@@ -7,11 +7,8 @@ import stat
 # external imports
 import confini
 
-# local imports
-from .base import (
-        Flag,
-        default_config_dir as default_parent_config_dir,
-        )
+script_dir = os.path.dirname(os.path.realpath(__file__))
+default_parent_config_dir = os.path.join(script_dir, '..', 'data', 'config')
 
 logg = logging.getLogger(__name__)
 
@@ -51,7 +48,7 @@ class Config(confini.Config):
         return super(Config, self).add_override_dir(v)
 
 
-def process_config(config, arg, args, flags):
+def process_config(config, arg, args, flags, positional_name=None):
 
     if arg.match('env', flags):
         config.set_env_prefix(getattr(args, 'env_prefix'))
@@ -61,7 +58,8 @@ def process_config(config, arg, args, flags):
     args_override = {}
 
     if arg.match('raw', flags):
-        config.add(getattr(args, 'raw', None), '_RAW')
+        config.add(getattr(args, 'r', None), '_RAW')
+        config.add(getattr(args, '0', None), '_NOLINE')
  
     if arg.match('provider', flags):
         args_override['RPC_PROVIDER'] = getattr(args, 'p')
@@ -126,6 +124,9 @@ def process_config(config, arg, args, flags):
     if arg.match('wallet', flags):    
         config.add(getattr(args, 'recipient'), '_RECIPIENT')
 
+    if arg.match('value', flags):
+        config.add(getattr(args, 'total'), '_TOTAL')
+
     if arg.match('exec', flags):
         config.add(getattr(args, 'executable_address'), '_EXEC_ADDRESS')
 
@@ -133,5 +134,13 @@ def process_config(config, arg, args, flags):
         config.add(getattr(args, 'rpc_auth'), 'RPC_AUTH')
         config.add(getattr(args, 'rpc_credentials'), 'RPC_CREDENTIALS')
 
+    if positional_name != None:
+        config.add(None, '_POSARG', False)
+        pos_arg = getattr(args, positional_name)
+        if len(pos_arg) > 0:
+            config.add(pos_arg[0], '_POSARG', True)
+
+    if arg.match('tab', flags):
+        config.add(args.o, '_OUTARG', False)
 
     return config
